Struct XxToplevelSessionV1
pub struct XxToplevelSessionV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
xx_toplevel_session_v1
See also the Event enum for this interface.
Implementations
impl XxToplevelSessionV1
impl XxToplevelSessionV1
pub fn destroy(&self)
pub fn destroy(&self)
Destroy the object
Destroy the object. This has no effect window management of the associated toplevel.
pub fn remove(&self)
pub fn remove(&self)
remove a surface from the session
Remove a specified surface from the session and render any corresponding xx_toplevel_session_v1 object inert. The compositor should remove any data related to the toplevel in the corresponding session from its internal storage.